pub struct ModelAtomView<'a> { /* private fields */ }Expand description
Read-only view into a single atom from a Model.
Implementations
Sourceimpl<'a> ModelAtomView<'a>
impl<'a> ModelAtomView<'a>
Sourcepub fn coords(&self) -> [f32; 3]
pub fn coords(&self) -> [f32; 3]
[x, y, z] for this atom (AoS convenience; allocation-free from SoA).
Sourcepub fn element(&self) -> Element
pub fn element(&self) -> Element
Element parsed from the symbol stored in the hierarchy.
Returns Element::C for unrecognised symbols.
pub fn atom_name(&self) -> &'a str
pub fn residue_id(&self) -> i32
pub fn residue_name(&self) -> &'a str
pub fn chain_id(&self) -> &'a str
pub fn is_hetero(&self) -> bool
pub fn index(&self) -> usize